==> util-hooks-1.2.0.tgz: package/es/useDebounce.js <==
import { useRef, useEffect, useMemo } from 'react';
/**
 * useDebounce
 * Creates a stable-identity debounced function.
 * The wrapped function has two methods attached:
 *    `.cancel()` to cancel any pending invocations
 *    `.flush()` to immediately execute an pending invocations
 * The wrapped function returns a Promise that will be resolved with the return value of the debounced function once its execution is completed.
 * @param fn the function to be debounced
 * @param ms duration in milliseconds since the last invocation that must elapse before the next invocation is executed
 */

export default function useDebounce(fn, ms) {
  const callback = useRef(fn);
  const args = useRef([]);
  const context = useRef();
  const returnValueResolve = useRef(() => {});
  const timeoutId = useRef();
  useEffect(() => {
    callback.current = fn;
  }, [fn]);
  return useMemo(() => {
    const execute = () => {
      timeoutId.current = undefined;
      const resolve = returnValueResolve.current;
      resolve(callback.current.apply(context.current, args.current));
    };

    const cancel = () => {
      if (timeoutId.current) {
        window.clearTimeout(timeoutId.current);
        timeoutId.current = undefined;
        return true;
      }

      return false;
    };

    const flush = () => {
      if (cancel()) {
        execute();
      }
    };

    function debouncedFn(..._args) {
      cancel();
      args.current = _args;
      context.current = this;
      timeoutId.current = window.setTimeout(execute, ms);
      return new Promise(resolve => {
        returnValueResolve.current = resolve;
      });
    }

    return Object.assign(debouncedFn, {
      cancel,
      flush
    });
  }, [ms]);
}

==> util-hooks-1.3.1.tgz: package/es/useDebounce.js <==
import { useRef, useEffect, useMemo } from 'react';
/**
 * useDebounce
 * Creates a stable-identity debounced function.
 * The wrapped function has two methods attached:
 *    `.cancel()` to cancel any pending invocations
 *    `.flush()` to immediately execute an pending invocations
 * The wrapped function returns a Promise that will be resolved with the return value of the debounced function once its execution is completed.
 * @param fn the function to be debounced
 * @param ms duration in milliseconds since the last invocation that must elapse before the next invocation is executed
 */

export default function useDebounce(fn, ms) {
  var callback = useRef(fn);
  var args = useRef([]);
  var context = useRef();
  var returnValueResolve = useRef(() => {});
  var timeoutId = useRef();
  useEffect(() => {
    callback.current = fn;
  }, [fn]);
  return useMemo(() => {
    var execute = () => {
      timeoutId.current = undefined;
      var resolve = returnValueResolve.current;
      resolve(callback.current.apply(context.current, args.current));
    };

    var cancel = () => {
      if (timeoutId.current) {
        window.clearTimeout(timeoutId.current);
        timeoutId.current = undefined;
        return true;
      }

      return false;
    };

    var flush = () => {
      if (cancel()) {
        execute();
      }
    };

    function debouncedFn() {
      cancel();

      for (var _len = arguments.length, _args = new Array(_len), _key = 0; _key < _len; _key++) {
        _args[_key] = arguments[_key];
      }

      args.current = _args;
      context.current = this;
      timeoutId.current = window.setTimeout(execute, ms);
      return new Promise(resolve => {
        returnValueResolve.current = resolve;
      });
    }

    return Object.assign(debouncedFn, {
      cancel,
      flush
    });
  }, [ms]);
}
